@@ -76,9 +76,7 @@ class McDropout(Model):
             raise ValueError("Error in McDropout.evaluate(). Targets and inputs not of equal length.")
 
         # Returns: (batch_size, sample_size, target_len) or (batch_size, target_len)
-        self.logger.info("evaluate/call")
         predictions = self.__call__(inputs, sample_size=sample_size, **kwargs)
-        self.logger.info("evaluate/predictions.shape: {}".format(predictions.shape))
         loss, acc = self.__evaluate(predictions, targets, sample_size)
         return {"loss": loss, "accuracy": acc}
 
@@ -216,9 +214,7 @@ class McDropout(Model):
             Parameters:
                 model (tf.Model) The tensorflow model to use for selection of datapoints
                 unlabeled_pool (Pool) The pool of unlabeled data to select
-        """
-        self.logger.info("----------Max-Entropy-------------")
-        
+        """        
         # Create predictions
         predictions = self.__call__(data, sample_size=sample_size)
         expectation = self.expectation(predictions)
@@ -232,15 +228,9 @@ class McDropout(Model):
 
     def __bald(self, data, sample_size=10, **kwargs):
         # TODO: dimensions do not line up in mutli class
-        
-        self.logger.info("------------ BALD -----------")
         # predictions shape (batch, num_predictions, num_classes)
-        self.logger.info("_bald/data-shape: {}".format(data.shape))
         predictions = self.__call__(data, sample_size=sample_size)
-
-        self.logger.info("_bald/predictions-shape: {}".format(predictions.shape))
         posterior = self.expectation(predictions)
-        self.logger.info("_bald/posterior-shape: {}".format(posterior.shape))
 
         first_term = -np.sum(posterior*np.log(np.abs(posterior) + .001), axis=1)
 
@@ -248,12 +238,7 @@ class McDropout(Model):
         predictions = self.extend_binary_predictions(predictions)
         
         inner_sum = np.sum(predictions*np.log(np.abs(predictions) + .001), axis=1)
-        self.logger.info("_bald/inner-shape: {}".format(inner_sum.shape))
-
         second_term = np.sum(inner_sum, axis=1)/predictions.shape[1]
-
-        self.logger.info("_bald/first-term-shape: {}".format(first_term.shape))
-        self.logger.info("_bald/second-term-shape: {}".format(second_term.shape))
         return first_term + second_term
 
 
@@ -264,10 +249,6 @@ class McDropout(Model):
             # (batch, predictions, classes) reduce to (batch, predictions (max-class))
             # 1 - (count of most common class / num predictions)
         """
-        self.logger.info("----------Max-Var-Ratio--------------")
-
-        # (batch, sample, num classses)
-        # (batch, num_classes)
         predictions = self.__call__(data, sample_size=sample_size)
         posterior = self.expectation(predictions)
 
@@ -284,8 +265,6 @@ class McDropout(Model):
            Todo:
             Implement distinction for different model types.
         """
-        self.logger.info("----------Std-Mean-------------")
-
         # TODO: generalize for n-classes For binary classes
         predictions = self.__call__(data, sample_size=sample_size)
 
@@ -302,9 +281,6 @@ class McDropout(Model):
             Select sample which minimize distance between two most probable labels.
             Margin Sampling (MS).
         """
-
-        self.logger.info("----------Margin-Sampling-------------")
-
         predictions = self.__call__(data, sample_size=sample_size)
         expectation = self.expectation(predictions)
 
@@ -316,9 +292,6 @@ class McDropout(Model):
             Select sample which minimize distance between two most probable labels.
             Margin Sampling (MS).
         """
-
-        self.logger.info("----------Margin-Sampling-------------")
-
         predictions = self.__call__(data, sample_size=sample_size)
         expectation = self.expectation(predictions)
 
